==> chunksfadein-fabric-3.0.8-1.21.6-sources.jar: com/koteinik/chunksfadein/compat/mc/mixin/ItemFrameEntityRendererMixin.java <==

package com.koteinik.chunksfadein.compat.mc.mixin;

import com.koteinik.chunksfadein.compat.sodium.ext.SodiumWorldRendererExt;
import com.koteinik.chunksfadein.config.Config;
import net.caffeinemc.mods.sodium.client.render.SodiumWorldRenderer;
import net.minecraft.class_10040;
import net.minecraft.class_243;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_915;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(value = class_915.class)
public class ItemFrameEntityRendererMixin {
	@Inject(
		method = "render(Lnet/minecraft/client/renderer/entity/state/ItemFrameRenderState;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/MultiBufferSource;I)V",
		at = @At(
			value = "INVOKE",
			target = "Lcom/mojang/blaze3d/vertex/PoseStack;mulPose(Lorg/joml/Quaternionfc;)V",
			ordinal = 1
		)
	)
	private void modifyRender(class_10040 state, class_4587 stack, class_4597 multiBufferSource, int i, CallbackInfo ci) {
		if (!Config.isModEnabled || (!Config.isAnimationEnabled && !Config.isCurvatureEnabled) || state.field_53334)
			return;

		SodiumWorldRenderer renderer = SodiumWorldRenderer.instanceNullable();
		if (renderer == null)
			return;

		if (((SodiumWorldRendererExt) renderer).getRenderSectionManager() == null)
			return;

		float[] offset = ((SodiumWorldRendererExt) renderer).getAnimationOffset(new class_243(state.field_53325, state.field_53326, state.field_53327));
		if (offset == null)
			return;

		stack.method_46416(offset[0], offset[1], offset[2]);
	}
}

==> chunksfadein-fabric-3.0.12-1.21.9-sources.jar: com/koteinik/chunksfadein/compat/mc/mixin/ItemFrameEntityRendererMixin.java <==
package com.koteinik.chunksfadein.compat.mc.mixin;

import com.koteinik.chunksfadein.compat.sodium.ext.SodiumWorldRendererExt;
import com.koteinik.chunksfadein.config.Config;
import net.caffeinemc.mods.sodium.client.render.SodiumWorldRenderer;
import net.minecraft.class_10040;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_243;
import net.minecraft.class_4587;
import net.minecraft.class_915;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(value = class_915.class)
public class ItemFrameEntityRendererMixin {
	@Inject(
		method = "submit(Lnet/minecraft/client/renderer/entity/state/ItemFrameRenderState;Lcom/mojang/blaze3d/vertex/PoseStack;Lnet/minecraft/client/renderer/SubmitNodeCollector;Lnet/minecraft/client/renderer/state/CameraRenderState;)V",
		at = @At(value = "INVOKE", target = "Lcom/mojang/blaze3d/vertex/PoseStack;popPose()V")
	)
	private void modifyRender(class_10040 state, class_4587 stack, class_11659 submitNodeCollector, class_12075 cameraRenderState, CallbackInfo ci) {
		if (!Config.isModEnabled || (!Config.isAnimationEnabled && !Config.isCurvatureEnabled) || state.field_53334)
			return;

		SodiumWorldRenderer renderer = SodiumWorldRenderer.instanceNullable();
		if (renderer == null)
			return;

		if (((SodiumWorldRendererExt) renderer).getRenderSectionManager() == null)
			return;

		float[] offset = ((SodiumWorldRendererExt) renderer).getAnimationOffset(new class_243(state.field_53325, state.field_53326, state.field_53327));
		if (offset == null)
			return;

		stack.method_46416(offset[0], offset[1], offset[2]);
	}
}
